(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    128222,       3548]
NotebookOptionsPosition[    123912,       3394]
NotebookOutlinePosition[    124253,       3409]
CellTagsIndexPosition[    124210,       3406]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Gaussian Archive Reader", "Subtitle"],

Cell[TextData[{
 "This ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook extracts data from the archive entry at the end of a Gaussian \
frequency output file.\nCut and paste the archive lines into a text file and  \
assign the file name to ArchiveFile.\nThe Cartesian coordinates, dipole \
moment, dipole derivatives, polarizability, polarizability derivatives, \
hessian, etc. are extracted.\nThe vibrational frequencies, intensities and \
normal modes are computed with the most abundant masses. \nThe dipole \
derivatives and polarizability derivatives are calculated for each normal \
mode.\n\nThis ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook can be the starting point for further calculations involving \
these quantities."
}], "Text",
 CellChangeTimes->{{3.422719481671875*^9, 3.42271952934375*^9}, {
   3.422719608015625*^9, 3.422719658234375*^9}, {3.422719713515625*^9, 
   3.422719743265625*^9}, {3.422719775234375*^9, 3.42271997109375*^9}, 
   3.422720020828125*^9, {3.42272013259375*^9, 3.422720182734375*^9}, 
   3.422720255890625*^9, {3.4228817293082*^9, 3.422881791521*^9}}],

Cell[CellGroupData[{

Cell["Set working directory, indexing functions, etc.", "Subsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  "\"\<C:\\Documents and Settings\\Berny\\Desktop\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.422709963390625*^9, 3.422709968328125*^9}}],

Cell[BoxData["\<\"C:\\\\Documents and Settings\\\\Berny\\\\Desktop\"\>"], \
"Output",
 CellChangeTimes->{3.422710221109375*^9, 3.4227193739375*^9, 
  3.42272034409375*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ArchiveFile", "=", "\"\<archive.txt\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.422719686*^9, 3.42271968975*^9}, {3.42271975296875*^9, 
  3.422719760015625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lin", "[", 
   RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"i", ">", "j"}], ",", 
    RowBox[{
     RowBox[{"i", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"i", "-", "1"}], ")"}], "/", "2"}]}], "+", "j"}], ",", 
    RowBox[{
     RowBox[{"j", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"j", "-", "1"}], ")"}], "/", "2"}]}], "+", "i"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tri", "[", 
   RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"i", ">", "j"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"j", ">", "k"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}], "i", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"i", "-", "1"}], ")"}], "/", "6"}]}], "+", 
       RowBox[{"j", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"j", "-", "1"}], ")"}], "/", "2"}]}], "+", "k"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", ">", "k"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"i", "+", "1"}], ")"}], "i", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "-", "1"}], ")"}], "/", "6"}]}], "+", 
         RowBox[{"k", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"k", "-", "1"}], ")"}], "/", "2"}]}], "+", "j"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"k", "+", "1"}], ")"}], "k", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"k", "-", "1"}], ")"}], "/", "6"}]}], "+", 
         RowBox[{"i", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "-", "1"}], ")"}], "/", "2"}]}], "+", "j"}]}], 
       "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"j", "<", "k"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "+", "1"}], ")"}], "k", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k", "-", "1"}], ")"}], "/", "6"}]}], "+", 
       RowBox[{"j", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"j", "-", "1"}], ")"}], "/", "2"}]}], "+", "i"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", ">", "k"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"j", "+", "1"}], ")"}], "j", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"j", "-", "1"}], ")"}], "/", "6"}]}], "+", 
         RowBox[{"i", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "-", "1"}], ")"}], "/", "2"}]}], "+", "k"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"j", "+", "1"}], ")"}], "j", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"j", "-", "1"}], ")"}], "/", "6"}]}], "+", 
         RowBox[{"k", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"k", "-", "1"}], ")"}], "/", "2"}]}], "+", "i"}]}], 
       "]"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Read archive as a string (remove blanks and line feeds)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"in", "=", 
  RowBox[{"StringReplace", "[", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{"ArchiveFile", ",", "\"\<TEXT\>\""}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FromCharacterCode", "[", 
       RowBox[{"{", 
        RowBox[{"10", ",", "32"}], "}"}], "]"}], "->", "\"\<\>\""}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.422719696015625*^9, 3.42271969653125*^9}, 
   3.422719768171875*^9}],

Cell[BoxData["\<\" \
1|1|UNPC-UNK|Freq|RHF|6-31G(d,p)|C1H2O1|PCUSER|03-Feb-2005|0||#N \
GEOM=ALLCHECK GUESS=READ SCRF=CHECK GENCHK RHF/6-31G(D,P) \
FREQ||Formaldehyde||0,1|C,0.,0.,-0.5195128352|O,0.,0.,0.664930014|H,0.\
9258005977,0.,-1.1011815507|H,-0.9258005977,0.,-1.1011815507||Version=x86-\
Win32-G03RevB.03|State=1-A1|HF=-113.8697432|RMSD=5.311e-010|RMSF=1.151e-005|\
Dipole=0.,0.,-1.0476516|DipoleDeriv=0.9335424,0.,0.,0.,0.2678781,0.,0.,0.,1.\
1681456,-0.5373151,0.,0.,0.,-0.4021318,0.,0.,0.,-1.0808668,-0.1981136,0.,0.\
1027287,0.,0.0671269,0.,0.0801724,0.,-0.0436394,-0.1981136,0.,-0.1027287,0.,0.\
0671269,0.,-0.0801724,0.,-0.0436394|Polar=13.0897661,0.,6.7144504,0.,0.,17.\
8240687|PolarDeriv=0.,0.,0.,3.1240119,0.,0.,0.,0.,0.,0.,-2.1625593,0.,9.\
2873123,0.,-0.9737418,0.,0.,-5.1314594,0.,0.,0.,3.381628,0.,0.,0.,0.,0.,0.,4.\
0409969,0.,-3.0806182,0.,1.2112966,0.,0.,11.2823935,7.044524,0.,0.5063217,-3.\
2528199,0.,1.3282562,0.,1.8220295,0.,0.,-0.9392188,0.,-3.103347,0.,-0.1187774,\
2.8538474,0.,-3.075467,-7.044524,0.,-0.5063217,-3.2528199,0.,-1.3282562,0.,-1.\
8220295,0.,0.,-0.9392188,0.,-3.103347,0.,-0.1187774,-2.8538474,0.,-3.075467|\
HyperPolar=0.,0.,0.,0.,-37.9314839,0.,-3.351018,0.,0.,-36.9708509|PG=C02V \
[C2(C1O1),SGV(H2)]|NImag=0||0.67562401,0.,0.21551931,0.,0.,1.22849404,-0.\
12384756,0.,0.,0.08648406,0.,-0.07098765,0.,0.,0.02338454,0.,0.,-0.99475835,0.\
,0.,1.08831872,-0.27588822,0.,0.09179313,0.01868175,0.,0.01744064,0.27786336,\
0.,-0.07226583,0.,0.,0.02380155,0.,0.,0.02423810,0.09411962,0.,-0.11686785,0.\
04358057,0.,-0.04678019,-0.12346698,0.,0.15296548,-0.27588822,0.,-0.09179313,\
0.01868175,0.,-0.01744064,-0.02065689,0.,-0.01423321,0.27786336,0.,-0.\
07226583,0.,0.,0.02380155,0.,0.,0.02422618,0.,0.,0.02423810,-0.09411962,0.,-0.\
11686785,-0.04358057,0.,-0.04678019,0.01423321,0.,0.01068256,0.12346698,0.,0.\
15296548||0.,0.,-0.00002129,0.,0.,0.00001591,0.00002085,0.,0.00000269,-0.\
00002085,0.,0.00000269|||@\\n\"\>"], "Output",
 CellChangeTimes->{3.42271022146875*^9, 3.422719374078125*^9, 
  3.422720344375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get atomic symbols and Cartesian coordinates ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{
    RowBox[{"StringPosition", "[", 
     RowBox[{"in", ",", "\"\<|\>\""}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"16", ",", "2"}], "]"}], "]"}]}], ";", 
  RowBox[{"end", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<||Version\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "2"}]}], ";", 
  RowBox[{"Natoms", "=", 
   RowBox[{"StringCount", "[", 
    RowBox[{
     RowBox[{"StringTake", "[", 
      RowBox[{"in", ",", 
       RowBox[{"{", 
        RowBox[{"start", ",", "end"}], "}"}]}], "]"}], ",", "\"\<|\>\""}], 
    "]"}]}], ";", 
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"in", ",", 
        RowBox[{"{", 
         RowBox[{"start", ",", "end"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], ",", 
        RowBox[{"\"\<|\>\"", "->", "\"\<\>\""}]}], "}"}]}], "]"}], "]"}]}], 
  ";", 
  RowBox[{"tmp", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Read", "[", 
      RowBox[{"str", ",", 
       RowBox[{"{", 
        RowBox[{"Word", ",", "Number", ",", "Number", ",", "Number"}], 
        "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Natoms"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"coord", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"tmp", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", 
       RowBox[{"tmp", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "4"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"AtNames", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tmp", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", "Natoms"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"AtNames", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<  \>\"", ",", 
      RowBox[{"coord", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "\"\<  \>\"", ",", 
      RowBox[{"coord", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "\"\<  \>\"", ",", 
      RowBox[{"coord", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4227105274375*^9, 3.422710541890625*^9}, {
  3.4227105763125*^9, 3.42271072065625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"C\"\>", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]",
    "0.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.5195128352`"}]}],
  SequenceForm["C", "  ", 0., "  ", 0., "  ", -0.5195128352],
  Editable->False]], "Print",
 CellChangeTimes->{3.422710725109375*^9, 3.422719374171875*^9, 
  3.4227203445*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"O\"\>", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]",
    "0.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", "0.664930014`"}],
  SequenceForm["O", "  ", 0., "  ", 0., "  ", 0.664930014],
  Editable->False]], "Print",
 CellChangeTimes->{3.422710725109375*^9, 3.422719374171875*^9, 
  3.422720344671875*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"H\"\>", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]",
    "0.9258005977`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.1011815507`"}]}],
  SequenceForm["H", "  ", 0.9258005977, "  ", 0., "  ", -1.1011815507],
  Editable->False]], "Print",
 CellChangeTimes->{3.422710725109375*^9, 3.422719374171875*^9, 
  3.422720354765625*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"H\"\>", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]",
    
   RowBox[{"-", "0.9258005977`"}], "\[InvisibleSpace]", "\<\"  \"\>", 
   "\[InvisibleSpace]", "0.`", "\[InvisibleSpace]", "\<\"  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "1.10118155`"}]}],
  SequenceForm["H", "  ", -0.9258005977, "  ", 0., "  ", -1.10118155],
  Editable->False]], "Print",
 CellChangeTimes->{3.422710725109375*^9, 3.422719374171875*^9, 
  3.422720354875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get dipole moment ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|Dipole=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", "1"}]}], ";", 
  RowBox[{"end", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|DipoleDeriv=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], ";", 
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"in", ",", 
        RowBox[{"{", 
         RowBox[{"start", ",", "end"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], "}"}]}], "]"}], "]"}]}], ";",
   
  RowBox[{"dipole", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"str", ",", "Number"}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", "dipole"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.`", ",", 
   RowBox[{"-", "1.0476516`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4227193744375*^9, 3.42272035521875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get dipole derivatives", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|DipoleDeriv=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", "1"}]}], ";", 
  RowBox[{"end", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|Polar=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], ";", 
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"in", ",", 
        RowBox[{"{", 
         RowBox[{"start", ",", "end"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], "}"}]}], "]"}], "]"}]}], ";",
   
  RowBox[{"dipolederiv", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"ReadList", "[", 
      RowBox[{"str", ",", "Number"}], "]"}], ",", "3"}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", 
  RowBox[{"MatrixForm", "[", "dipolederiv", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.9335424`", "0.`", "0.`"},
     {"0.`", "0.2678781`", "0.`"},
     {"0.`", "0.`", "1.1681456`"},
     {
      RowBox[{"-", "0.5373151`"}], "0.`", "0.`"},
     {"0.`", 
      RowBox[{"-", "0.4021318`"}], "0.`"},
     {"0.`", "0.`", 
      RowBox[{"-", "1.0808668`"}]},
     {
      RowBox[{"-", "0.1981136`"}], "0.`", "0.1027287`"},
     {"0.`", "0.0671269`", "0.`"},
     {"0.0801724`", "0.`", 
      RowBox[{"-", "0.0436394`"}]},
     {
      RowBox[{"-", "0.1981136`"}], "0.`", 
      RowBox[{"-", "0.1027287`"}]},
     {"0.`", "0.0671269`", "0.`"},
     {
      RowBox[{"-", "0.0801724`"}], "0.`", 
      RowBox[{"-", "0.0436394`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.42271937453125*^9, 3.422720355375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get polarizabilities ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|Polar=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", "1"}]}], ";", 
  RowBox[{"end", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|PolarDeriv=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], ";", 
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"in", ",", 
        RowBox[{"{", 
         RowBox[{"start", ",", "end"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], "}"}]}], "]"}], "]"}]}], ";",
   
  RowBox[{"tmp", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"str", ",", "Number"}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", 
  RowBox[{"polar", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tmp", "[", 
      RowBox[{"[", 
       RowBox[{"lin", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"MatrixForm", "[", "polar", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"13.0897661`", "0.`", "0.`"},
     {"0.`", "6.7144504`", "0.`"},
     {"0.`", "0.`", "17.8240687`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.422719374640625*^9, 3.422720355484375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get polarizability derivatives", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|PolarDeriv=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", "1"}]}], ";", 
  RowBox[{"end", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|HyperPolar=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], ";", 
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"in", ",", 
        RowBox[{"{", 
         RowBox[{"start", ",", "end"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], "}"}]}], "]"}], "]"}]}], ";",
   
  RowBox[{"tmp", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"ReadList", "[", 
      RowBox[{"str", ",", "Number"}], "]"}], ",", "6"}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", 
  RowBox[{"polarderiv", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tmp", "[", 
      RowBox[{"[", 
       RowBox[{"k", ",", 
        RowBox[{"lin", "[", 
         RowBox[{"i", ",", "j"}], "]"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"MatrixForm", "[", "polarderiv", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"3.1240119`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"3.1240119`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {
           RowBox[{"-", "2.1625593`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "2.1625593`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"9.2873123`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "0.9737418`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {
           RowBox[{"-", "5.1314594`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"3.381628`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"3.381628`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"4.0409969`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"4.0409969`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "3.0806182`"}]},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"1.2112966`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"11.2823935`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"7.044524`"},
          {"0.`"},
          {
           RowBox[{"-", "3.2528199`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.5063217`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "3.2528199`"}]},
          {"0.`"},
          {"1.3282562`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"1.8220295`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"1.8220295`"},
          {"0.`"},
          {
           RowBox[{"-", "0.9392188`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "0.9392188`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "3.103347`"}]},
          {"0.`"},
          {"2.8538474`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "0.1187774`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"2.8538474`"},
          {"0.`"},
          {
           RowBox[{"-", "3.075467`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "7.044524`"}]},
          {"0.`"},
          {
           RowBox[{"-", "3.2528199`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "0.5063217`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "3.2528199`"}]},
          {"0.`"},
          {
           RowBox[{"-", "1.3282562`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "1.8220295`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "1.8220295`"}]},
          {"0.`"},
          {
           RowBox[{"-", "0.9392188`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "0.9392188`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "3.103347`"}]},
          {"0.`"},
          {
           RowBox[{"-", "2.8538474`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "0.1187774`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "2.8538474`"}]},
          {"0.`"},
          {
           RowBox[{"-", "3.075467`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.42271937475*^9, 3.422720355625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get first hyperpolarizabilities (beta) ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|HyperPolar=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", "1"}]}], ";", 
  RowBox[{"end", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|PG=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], ";", 
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"in", ",", 
        RowBox[{"{", 
         RowBox[{"start", ",", "end"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], "}"}]}], "]"}], "]"}]}], ";",
   
  RowBox[{"tmp", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"str", ",", "Number"}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", 
  RowBox[{"hyperpolar", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tmp", "[", 
      RowBox[{"[", 
       RowBox[{"tri", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"MatrixForm", "[", "hyperpolar", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {
           RowBox[{"-", "37.9314839`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "37.9314839`"}]},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {
           RowBox[{"-", "3.351018`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "3.351018`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "37.9314839`"}]},
          {"0.`"},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "3.351018`"}]},
          {"0.`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.`"},
          {
           RowBox[{"-", "36.9708509`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.422719374859375*^9, 3.42272035584375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get Hessian (force constants)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringPosition", "[", 
      RowBox[{"in", ",", "\"\<|NImag=\>\""}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", "4"}]}], ";", 
  RowBox[{"tmp1", "=", 
   RowBox[{"StringTake", "[", 
    RowBox[{"in", ",", 
     RowBox[{"{", 
      RowBox[{"start", ",", 
       RowBox[{"StringLength", "[", "in", "]"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"end", "=", 
   RowBox[{"StringPosition", "[", 
    RowBox[{"tmp1", ",", "\"\<||\>\""}], "]"}]}], ";", 
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"tmp1", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{
           RowBox[{"end", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], "}"}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], "}"}]}], "]"}], "]"}]}], ";",
   
  RowBox[{"tmp", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"str", ",", "Number"}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", 
  RowBox[{"hessian", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"tmp", "[", 
      RowBox[{"[", 
       RowBox[{"lin", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"MatrixForm", "[", "hessian", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.67562401`", "0.`", "0.`", 
      RowBox[{"-", "0.12384756`"}], "0.`", "0.`", 
      RowBox[{"-", "0.27588822`"}], "0.`", "0.09411962`", 
      RowBox[{"-", "0.27588822`"}], "0.`", 
      RowBox[{"-", "0.09411962`"}]},
     {"0.`", "0.21551931`", "0.`", "0.`", 
      RowBox[{"-", "0.07098765`"}], "0.`", "0.`", 
      RowBox[{"-", "0.07226583`"}], "0.`", "0.`", 
      RowBox[{"-", "0.07226583`"}], "0.`"},
     {"0.`", "0.`", "1.22849404`", "0.`", "0.`", 
      RowBox[{"-", "0.99475835`"}], "0.09179313`", "0.`", 
      RowBox[{"-", "0.11686785`"}], 
      RowBox[{"-", "0.09179313`"}], "0.`", 
      RowBox[{"-", "0.11686785`"}]},
     {
      RowBox[{"-", "0.12384756`"}], "0.`", "0.`", "0.08648406`", "0.`", "0.`",
       "0.01868175`", "0.`", "0.04358057`", "0.01868175`", "0.`", 
      RowBox[{"-", "0.04358057`"}]},
     {"0.`", 
      RowBox[{"-", "0.07098765`"}], "0.`", "0.`", "0.02338454`", "0.`", "0.`",
       "0.02380155`", "0.`", "0.`", "0.02380155`", "0.`"},
     {"0.`", "0.`", 
      RowBox[{"-", "0.99475835`"}], "0.`", "0.`", "1.08831872`", 
      "0.01744064`", "0.`", 
      RowBox[{"-", "0.04678019`"}], 
      RowBox[{"-", "0.01744064`"}], "0.`", 
      RowBox[{"-", "0.04678019`"}]},
     {
      RowBox[{"-", "0.27588822`"}], "0.`", "0.09179313`", "0.01868175`", 
      "0.`", "0.01744064`", "0.27786336`", "0.`", 
      RowBox[{"-", "0.12346698`"}], 
      RowBox[{"-", "0.02065689`"}], "0.`", "0.01423321`"},
     {"0.`", 
      RowBox[{"-", "0.07226583`"}], "0.`", "0.`", "0.02380155`", "0.`", "0.`",
       "0.0242381`", "0.`", "0.`", "0.02422618`", "0.`"},
     {"0.09411962`", "0.`", 
      RowBox[{"-", "0.11686785`"}], "0.04358057`", "0.`", 
      RowBox[{"-", "0.04678019`"}], 
      RowBox[{"-", "0.12346698`"}], "0.`", "0.15296548`", 
      RowBox[{"-", "0.01423321`"}], "0.`", "0.01068256`"},
     {
      RowBox[{"-", "0.27588822`"}], "0.`", 
      RowBox[{"-", "0.09179313`"}], "0.01868175`", "0.`", 
      RowBox[{"-", "0.01744064`"}], 
      RowBox[{"-", "0.02065689`"}], "0.`", 
      RowBox[{"-", "0.01423321`"}], "0.27786336`", "0.`", "0.12346698`"},
     {"0.`", 
      RowBox[{"-", "0.07226583`"}], "0.`", "0.`", "0.02380155`", "0.`", "0.`",
       "0.02422618`", "0.`", "0.`", "0.0242381`", "0.`"},
     {
      RowBox[{"-", "0.09411962`"}], "0.`", 
      RowBox[{"-", "0.11686785`"}], 
      RowBox[{"-", "0.04358057`"}], "0.`", 
      RowBox[{"-", "0.04678019`"}], "0.01423321`", "0.`", "0.01068256`", 
      "0.12346698`", "0.`", "0.15296548`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4227193750625*^9, 3.422720356171875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get gradient (- forces)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"str", "=", 
   RowBox[{"StringToStream", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{"tmp1", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"end", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", "1"}], ",", 
          RowBox[{
           RowBox[{"end", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", "1"}]}], "}"}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<,\>\"", "->", "\"\< \>\""}], "}"}]}], "]"}], "]"}]}], ";",
   
  RowBox[{"gradient", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"str", ",", "Number"}], "]"}]}], ";", 
  RowBox[{"Close", "[", "str", "]"}], ";", "gradient"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.`", ",", 
   RowBox[{"-", "0.00002129`"}], ",", "0.`", ",", "0.`", ",", "0.00001591`", 
   ",", "0.00002085`", ",", "0.`", ",", "2.69`*^-6", ",", 
   RowBox[{"-", "0.00002085`"}], ",", "0.`", ",", "2.69`*^-6"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.422719375171875*^9, 3.422720356328125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get atomic masses", "Subsection",
 CellChangeTimes->{{3.422710845015625*^9, 3.422710858140625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"elements", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<H\>\"", ",", "\"\<He\>\"", ",", "\"\<Li\>\"", ",", "\"\<Be\>\"", 
     ",", "\"\<B\>\"", ",", "\"\<C\>\"", ",", "\"\<N\>\"", ",", "\"\<O\>\"", 
     ",", "\"\<F\>\"", ",", "\"\<Ne\>\"", ",", "\"\<na\>\"", ",", 
     "\"\<Mg\>\"", ",", "\"\<Al\>\"", ",", "\"\<Si\>\"", ",", "\"\<P\>\"", 
     ",", "\"\<S\>\"", ",", "\"\<Cl\>\"", ",", "\"\<Ar\>\"", ",", "\"\<K\>\"",
      ",", "\"\<Ca\>\"", ",", "\"\<Sc\>\"", ",", "\"\<Ti\>\"", ",", 
     "\"\<V\>\"", ",", "\"\<Cr\>\"", ",", "\"\<Mn\>\"", ",", "\"\<Fe\>\"", 
     ",", "\"\<Co\>\"", ",", "\"\<Ni\>\"", ",", "\"\<Cu\>\"", ",", 
     "\"\<Zn\>\"", ",", "\"\<Ga\>\"", ",", "\"\<Ge\>\"", ",", "\"\<As\>\"", 
     ",", "\"\<Se\>\"", ",", "\"\<Br\>\"", ",", "\"\<Kr\>\"", ",", 
     "\"\<Rb\>\"", ",", "\"\<Sr\>\"", ",", "\"\<Y\>\"", ",", "\"\<Zr\>\"", 
     ",", "\"\<Nb\>\"", ",", "\"\<Mo\>\"", ",", "\"\<Tc\>\"", ",", 
     "\"\<Ru\>\"", ",", "\"\<Rh\>\"", ",", "\"\<Pd\>\"", ",", "\"\<Ag\>\"", 
     ",", "\"\<Cd\>\"", ",", "\"\<In\>\"", ",", "\"\<Sn\>\"", ",", 
     "\"\<Sb\>\"", ",", "\"\<Te\>\"", ",", "\"\<I\>\"", ",", "\"\<Xe\>\"", 
     ",", "\"\<Cs\>\"", ",", "\"\<Ba\>\"", ",", "\"\<La\>\"", ",", 
     "\"\<Ce\>\"", ",", "\"\<Pr\>\"", ",", "\"\<Nd\>\"", ",", "\"\<Pm\>\"", 
     ",", "\"\<Sm\>\"", ",", "\"\<Eu\>\"", ",", "\"\<Gd\>\"", ",", 
     "\"\<Tb\>\"", ",", "\"\<Dy\>\"", ",", "\"\<Ho\>\"", ",", "\"\<Er\>\"", 
     ",", "\"\<Tm\>\"", ",", "\"\<Yb\>\"", ",", "\"\<Lu\>\"", ",", 
     "\"\<Hf\>\"", ",", "\"\<Ta\>\"", ",", "\"\<W\>\"", ",", "\"\<Re\>\"", 
     ",", "\"\<Os\>\"", ",", "\"\<Ir\>\"", ",", "\"\<Pt\>\"", ",", 
     "\"\<Au\>\"", ",", "\"\<Hg\>\"", ",", "\"\<Tl\>\"", ",", "\"\<Pb\>\"", 
     ",", "\"\<Bi\>\"", ",", "\"\<Po\>\"", ",", "\"\<At\>\"", ",", 
     "\"\<Rn\>\"", ",", "\"\<Fr\>\"", ",", "\"\<Ra\>\"", ",", "\"\<Ac\>\"", 
     ",", "\"\<Th\>\"", ",", "\"\<Pa\>\"", ",", "\"\<U\>\"", ",", 
     "\"\<Np\>\"", ",", "\"\<Pu\>\"", ",", "\"\<Am\>\"", ",", "\"\<Cm\>\"", 
     ",", "\"\<Bk\>\"", ",", "\"\<Cf\>\"", ",", "\"\<Es\>\"", ",", 
     "\"\<Fm\>\"", ",", "\"\<Md\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"weights", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.007825`", ",", "4.002603`", ",", "7.016004`", ",", "9.012182`", ",", 
     "11.009305`", ",", "12.`", ",", "14.003074`", ",", "15.994914`", ",", 
     "18.998403`", ",", "19.992439`", ",", "22.989769`", ",", "23.985045`", 
     ",", "26.981541`", ",", "27.976928`", ",", "30.973763`", ",", 
     "31.972071`", ",", "34.968852`", ",", "39.962383`", ",", "38.963707`", 
     ",", "39.96259`", ",", "44.955913`", ",", "47.947946`", ",", 
     "50.943962`", ",", "51.940509`", ",", "54.938046`", ",", "55.934939`", 
     ",", "58.933197`", ",", "57.935347`", ",", "62.929599`", ",", 
     "63.929145`", ",", "68.92558`", ",", "73.921178`", ",", "74.921595`", 
     ",", "79.91652`", ",", "78.918336`", ",", "83.911506`", ",", "84.9117`", 
     ",", "87.9056`", ",", "88.9054`", ",", "89.9043`", ",", "92.906`", ",", 
     "97.9055`", ",", "98.9063`", ",", "101.9037`", ",", "102.9048`", ",", 
     "105.9032`", ",", "106.90509`", ",", "113.9036`", ",", "114.9041`", ",", 
     "117.9018`", ",", "120.9038`", ",", "129.9067`", ",", "126.9004`", ",", 
     "131.9042`", ",", "133.9051`", ",", "137.905`", ",", "138.9061`", ",", 
     "139.9053`", ",", "140.9074`", ",", "141.9075`", ",", "0.`", ",", 
     "151.9195`", ",", "152.9209`", ",", "157.9241`", ",", "158.925`", ",", 
     "163.9288`", ",", "164.9303`", ",", "165.9304`", ",", "168.9344`", ",", 
     "173.939`", ",", "174.9409`", ",", "179.9468`", ",", "180.948`", ",", 
     "183.951`", ",", "186.956`", ",", "189.9586`", ",", "192.9633`", ",", 
     "194.9648`", ",", "196.9666`", ",", "201.9706`", ",", "204.9745`", ",", 
     "207.9766`", ",", "208.9804`", ",", "208.9825`", ",", "210.9875`", ",", 
     "222.0175`", ",", "223.0198`", ",", "226.0254`", ",", "227.0278`", ",", 
     "232.0382`", ",", "231.0359`", ",", "238.0508`", ",", "237.048`", ",", 
     "242.0587`", ",", "243.0614`", ",", "246.0674`", ",", "247.0702`", ",", 
     "249.0748`", ",", "252.0829`", ",", "252.0827`", ",", "255.0906`"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.42271293353125*^9, 3.422713006625*^9}, 
   3.42271797075*^9, {3.422718607125*^9, 3.422718643875*^9}, {
   3.422718771484375*^9, 3.422719209078125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"atmass", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "Natoms"}], "]"}]}], ";", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", "Natoms"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "\[LessEqual]", "10"}], ",", 
       RowBox[{"j", "++"}], ",", 
       RowBox[{
        RowBox[{"atmass", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"StringMatchQ", "[", 
           RowBox[{
            RowBox[{"AtNames", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"elements", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ",", 
            RowBox[{"IgnoreCase", "\[Rule]", "True"}]}], "]"}], ",", 
          RowBox[{"weights", "[", 
           RowBox[{"[", "j", "]"}], "]"}], ",", 
          RowBox[{"atmass", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"atmass", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\< Atomic symbol \>\"", ",", 
         RowBox[{"AtNames", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< for atom \>\"", ",", "i",
          ",", "\"\< is undefined\>\""}], "]"}]}], "]"}]}]}], "]"}], ";", 
  RowBox[{"MatrixForm", "[", 
   RowBox[{"{", 
    RowBox[{"AtNames", ",", "atmass"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.42271790328125*^9, 3.422718019328125*^9}, {
  3.422718078796875*^9, 3.422718511890625*^9}, {3.42271856396875*^9, 
  3.422718584984375*^9}, {3.42271862728125*^9, 3.4227186356875*^9}, {
  3.422719227640625*^9, 3.42271932940625*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"C\"\>", "\<\"O\"\>", "\<\"H\"\>", "\<\"H\"\>"},
     {"12.`", "15.994914`", "1.007825`", "1.007825`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.42271801321875*^9, 3.42271802171875*^9}, {
   3.422718123046875*^9, 3.42271812878125*^9}, {3.422718349453125*^9, 
   3.422718378265625*^9}, {3.42271845684375*^9, 3.422718462953125*^9}, 
   3.422718513484375*^9, 3.42271858690625*^9, {3.422719360328125*^9, 
   3.42271937528125*^9}, 3.422720356484375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sqrt[mass] and inverse sqrt[mass] matrices for mass weighting\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sqrtmass", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "j"}], ",", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"atmass", "[", 
         RowBox[{"[", 
          RowBox[{"Ceiling", "[", 
           RowBox[{"i", "/", "3"}], "]"}], "]"}], "]"}], "]"}], ",", "0"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"invsqrtmass", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "j"}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"atmass", "[", 
          RowBox[{"[", 
           RowBox[{"Ceiling", "[", 
            RowBox[{"i", "/", "3"}], "]"}], "]"}], "]"}], "]"}]}], ",", "0"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Construct the projector to remove translation, rotation and the direction \
along the path (using the gradient)\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"sqrtmass", ".", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}], "]"}]}]}], ";", 
  RowBox[{"pr1", "=", 
   RowBox[{
    RowBox[{"IdentityMatrix", "[", 
     RowBox[{"3", "Natoms"}], "]"}], "-", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "tmp", ",", "tmp"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"tmp", ".", "tmp"}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"pr1", ".", "sqrtmass", ".", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}], "]"}]}]}], ";", 
  RowBox[{"pr2", "=", 
   RowBox[{"pr1", "-", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "tmp", ",", "tmp"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"tmp", ".", "tmp"}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"pr2", ".", "sqrtmass", ".", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}], "]"}]}]}], ";", 
  RowBox[{"pr3", "=", 
   RowBox[{"pr2", "-", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "tmp", ",", "tmp"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"tmp", ".", "tmp"}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"pr3", ".", "sqrtmass", ".", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          RowBox[{"coord", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "3"}], "]"}], "]"}]}], ",", 
         RowBox[{"coord", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}], "]"}]}]}], ";", 
  RowBox[{"pr4", "=", 
   RowBox[{"pr3", "-", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "tmp", ",", "tmp"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"tmp", ".", "tmp"}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"pr4", ".", "sqrtmass", ".", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"coord", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", "0", ",", 
         RowBox[{"-", 
          RowBox[{"coord", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}], "]"}]}]}], ";", 
  RowBox[{"pr5", "=", 
   RowBox[{"pr4", "-", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "tmp", ",", "tmp"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"tmp", ".", "tmp"}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"pr5", ".", "sqrtmass", ".", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"coord", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ",", 
         RowBox[{"coord", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "Natoms"}], "}"}]}], "]"}], "]"}]}]}], ";", 
  RowBox[{"projector", "=", 
   RowBox[{"pr5", "-", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "tmp", ",", "tmp"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"tmp", ".", "tmp"}], ")"}]}]}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construct the projected mass-weighted Hessian", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mwhessian", "=", 
  RowBox[{
  "projector", ".", "invsqrtmass", ".", "hessian", ".", "invsqrtmass", ".", 
   "projector"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.056301657684706075`", ",", "0.`", ",", 
     RowBox[{"-", "2.6566119096238516`*^-12"}], ",", 
     RowBox[{"-", "0.00893918987586453`"}], ",", "0.`", ",", 
     RowBox[{"-", "4.3719888820348274`*^-13"}], ",", 
     RowBox[{"-", "0.07933201202676883`"}], ",", "0.`", ",", 
     "0.027062794123154876`", ",", 
     RowBox[{"-", "0.07933201199695694`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.02706279411224618`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.017959103817668683`", ",", "0.`", ",", "0.`", ",", 
     RowBox[{"-", "0.0051232069707653986`"}], ",", "0.`", ",", "0.`", ",", 
     RowBox[{"-", "0.02078015108526626`"}], ",", "0.`", ",", "0.`", ",", 
     RowBox[{"-", "0.02078015108526626`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6566119096238516`*^-12"}], ",", "0.`", ",", 
     "0.10237450373328641`", ",", "3.067197537620636`*^-12", ",", "0.`", ",", 
     
     RowBox[{"-", "0.0718019127018236`"}], ",", "0.026395323690848255`", ",", 
     "0.`", ",", 
     RowBox[{"-", "0.03360561654578071`"}], ",", 
     RowBox[{"-", "0.026395323693900415`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.03360561654337357`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.008939189875864529`"}], ",", "0.`", ",", 
     "3.0671981881419397`*^-12", ",", "0.005407062158690575`", ",", "0.`", 
     ",", "5.047698370397313`*^-13", ",", "0.0046525579879974415`", ",", 
     "0.`", ",", "0.010856133500659185`", ",", "0.004652557953578158`", ",", 
     "0.`", ",", 
     RowBox[{"-", "0.010856133513253848`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "0.0051232069707653986`"}], ",", "0.`", ",", "0.`", ",", 
     "0.0014615010822241795`", ",", "0.`", ",", "0.`", ",", 
     "0.005927969233568038`", ",", "0.`", ",", "0.`", ",", 
     "0.005927969233568038`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.3719975556522073`*^-13"}], ",", "0.`", ",", 
     RowBox[{"-", "0.0718019127018236`"}], ",", "5.047702707206003`*^-13", 
     ",", "0.`", ",", "0.068041549018535`", ",", "0.004343890803114194`", ",",
      "0.`", ",", 
     RowBox[{"-", "0.011651409421921874`"}], ",", 
     RowBox[{"-", "0.004343890803616488`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.01165140942152573`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.07933201202676883`"}], ",", "0.`", ",", 
     "0.02639532369084826`", ",", "0.004652557987997446`", ",", "0.`", ",", 
     "0.004343890803114193`", ",", "0.27570638910624756`", ",", "0.`", ",", 
     RowBox[{"-", "0.12250901016644114`"}], ",", 
     RowBox[{"-", "0.020496076582479067`"}], ",", "0.`", ",", 
     "0.014123357901728008`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "0.020780151085266256`"}], ",", "0.`", ",", "0.`", ",", 
     "0.005927969233568038`", ",", "0.`", ",", "0.`", ",", 
     "0.024044333364878746`", ",", "0.`", ",", "0.`", ",", 
     "0.024044333364878746`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.027062794123154876`", ",", "0.`", ",", 
     RowBox[{"-", "0.03360561654578071`"}], ",", "0.010856133500659178`", ",",
      "0.`", ",", 
     RowBox[{"-", "0.011651409421921874`"}], ",", 
     RowBox[{"-", "0.12250901016644114`"}], ",", "0.`", ",", 
     "0.15177651426511238`", ",", 
     RowBox[{"-", "0.014123357881954943`"}], ",", "0.`", ",", 
     "0.010600922253995474`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.07933201199695696`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.026395323693900415`"}], ",", "0.004652557953578159`", 
     ",", "0.`", ",", 
     RowBox[{"-", "0.004343890803616487`"}], ",", 
     RowBox[{"-", "0.020496076582479053`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.01412335788195495`"}], ",", "0.27570638914049783`", ",", 
     "0.`", ",", "0.12250901015920099`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "0.020780151085266256`"}], ",", "0.`", ",", "0.`", ",", 
     "0.005927969233568038`", ",", "0.`", ",", "0.`", ",", 
     "0.024044333364878746`", ",", "0.`", ",", "0.`", ",", 
     "0.024044333364878746`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.027062794112246172`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.03360561654337357`"}], ",", 
     RowBox[{"-", "0.010856133513253846`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.011651409421525734`"}], ",", "0.014123357901728`", ",", 
     "0.`", ",", "0.010600922253995476`", ",", "0.12250901015920097`", ",", 
     "0.`", ",", "0.1517765142552281`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.42271937553125*^9, 3.4227203566875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Get the eigenvalues and eigenvectors, and convert them into frequencies and \
normal modes\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"Eigensystem", "[", "mwhessian", "]"}]}], ";", 
  RowBox[{"freq", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"5140.49", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"tmp", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i"}], "]"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"3", "Natoms"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"modes", "=", 
   RowBox[{
    RowBox[{"tmp", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ".", "invsqrtmass"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.422719399578125*^9, 3.422719426328125*^9}}],

Cell[CellGroupData[{

Cell[BoxData["freq"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3195.2223358140714`", ",", "3120.2712426042526`", ",", 
   "2025.2644570881696`", ",", "1668.2929337657033`", ",", 
   "1376.7855996819897`", ",", "1335.6301983179103`", ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.000028752553318012558`", " ", "\[ImaginaryI]"}]}], ",", 
   "0.00002365447745886729`", ",", "0.000018723475569379128`", ",", 
   "1.515392335368683`*^-6", ",", "1.515392335368683`*^-6", ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"1.261353280889911`*^-12", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.422719375765625*^9, {3.422719414890625*^9, 3.422719431296875*^9}, 
   3.422720356828125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["modes"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.09535321415669093`", ",", 
     RowBox[{"-", "8.080463905619072`*^-17"}], ",", 
     RowBox[{"-", "9.575014065091751`*^-16"}], ",", 
     RowBox[{"-", "0.0003797556158698348`"}], ",", "1.0756497347020866`*^-18",
      ",", "1.0615977144894025`*^-17", ",", 
     RowBox[{"-", "0.5646637121838892`"}], ",", "1.7465516121510542`*^-17", 
     ",", "0.3509156290440788`", ",", 
     RowBox[{"-", "0.564663712183868`"}], ",", "1.7465516121510542`*^-17", 
     ",", 
     RowBox[{"-", "0.3509156290440676`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7364543594459025`*^-11"}], ",", 
     "1.5498315272070272`*^-17", ",", "0.0600323914382586`", ",", 
     "1.7366813499548204`*^-11", ",", 
     RowBox[{"-", "8.855482971362335`*^-18"}], ",", 
     RowBox[{"-", "0.0013566308474644222`"}], ",", "0.5953938571004816`", ",",
      
     RowBox[{"-", "3.0467348527374757`*^-18"}], ",", 
     RowBox[{"-", "0.34663235362234224`"}], ",", 
     RowBox[{"-", "0.5953938571693481`"}], ",", 
     RowBox[{"-", "3.0467348527374757`*^-18"}], ",", 
     RowBox[{"-", "0.3466323535680558`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.924297556277311`*^-12"}], ",", 
     "2.5392946639605487`*^-17", ",", 
     RowBox[{"-", "0.2154167531901241`"}], ",", "4.924555444354446`*^-12", 
     ",", "1.2922452218786746`*^-17", ",", "0.15366021728412724`", ",", 
     "0.1688320932356932`", ",", 
     RowBox[{"-", "1.925865386948342`*^-17"}], ",", "0.06311565876270298`", 
     ",", 
     RowBox[{"-", "0.16883209325521667`"}], ",", 
     RowBox[{"-", "1.925865386948342`*^-17"}], ",", "0.06311565877810077`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.809420351089262`*^-12"}], ",", 
     "5.1323773546173176`*^-17", ",", "0.0018622752747002546`", ",", 
     "9.810046757498403`*^-12", ",", "3.088974066728963`*^-17", ",", 
     RowBox[{"-", "0.0747326635037547`"}], ",", "0.33633280656368497`", ",", 
     RowBox[{"-", "7.645112935510275`*^-17"}], ",", "0.5819439001841459`", 
     ",", 
     RowBox[{"-", "0.3363328066025786`"}], ",", 
     RowBox[{"-", "7.645112935510275`*^-17"}], ",", "0.5819439002148226`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.1281977871910948`", ",", "2.504783732982513`*^-16", ",", 
     "1.4305461605994503`*^-16", ",", 
     RowBox[{"-", "0.06864234883739107`"}], ",", 
     RowBox[{"-", "5.097524147338774`*^-17"}], ",", 
     "2.0468285353955628`*^-16", ",", 
     RowBox[{"-", "0.2185126286215721`"}], ",", 
     RowBox[{"-", "8.255137951797396`*^-16"}], ",", 
     RowBox[{"-", "0.5595874098036842`"}], ",", 
     RowBox[{"-", "0.21851262862156745`"}], ",", 
     RowBox[{"-", "8.255137951797396`*^-16"}], ",", "0.559587409803679`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.392913933533437`*^-16"}], ",", 
     RowBox[{"-", "0.14889153123393647`"}], ",", "6.435684448582711`*^-18", 
     ",", "1.19572450241384`*^-16", ",", "0.036789755773330234`", ",", 
     "1.770053576257677`*^-17", ",", "1.9324732075786424`*^-16", ",", 
     "0.594472946757531`", ",", "6.784368685552434`*^-16", ",", 
     "4.172207129822798`*^-16", ",", "0.5944729467575309`", ",", 
     RowBox[{"-", "8.70397507200455`*^-16"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.17708281596143888`"}], ",", "0.16717659882871136`", ",", 
     
     RowBox[{"-", "0.002949798115452021`"}], ",", 
     RowBox[{"-", "0.03142758453424399`"}], ",", "0.014894371740032991`", ",",
      
     RowBox[{"-", "0.0029497981154520173`"}], ",", 
     RowBox[{"-", "0.24861272677759672`"}], ",", "0.24196096468534953`", ",", 
     
     RowBox[{"-", "0.11679885415433827`"}], ",", 
     RowBox[{"-", "0.24861272669151505`"}], ",", "0.24196096468534953`", ",", 
     "0.11089925792343432`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.042244367034219424`", ",", "0.12739096446998985`", ",", 
     "0.15190592209940715`", ",", "0.02689769722541873`", ",", 
     RowBox[{"-", "0.003969477163014023`"}], ",", "0.1519059220994071`", ",", 
     "0.04978097187835945`", ",", "0.19190083876051647`", ",", 
     "0.1639013983617601`", ",", "0.04978097186928951`", ",", 
     "0.19190083876051753`", ",", "0.13991044583705445`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.09036110985190124`", ",", "0.22903390887253977`", ",", 
     RowBox[{"-", "0.004041258151561334`"}], ",", "0.007839497269464342`", 
     ",", "0.02040546466264501`", ",", 
     RowBox[{"-", "0.0040412581515613276`"}], ",", "0.13088669572059478`", 
     ",", "0.3314893706698541`", ",", "0.06046042574444868`", ",", 
     "0.13088669567182487`", ",", "0.3314893706698541`", ",", 
     RowBox[{"-", "0.06854294204757128`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.008103941234932065`"}], ",", 
     RowBox[{"-", "0.07730863813111685`"}], ",", "0.011866123612246489`", ",",
      
     RowBox[{"-", "0.1988512428257086`"}], ",", 
     RowBox[{"-", "0.09205783642890707`"}], ",", "0.011866123612246496`", ",",
      "0.08557026007949817`", ",", 
     RowBox[{"-", "0.07006544591702689`"}], ",", "0.16096066704393563`", ",", 
     "0.08557025996676733`", ",", 
     RowBox[{"-", "0.07006544591701282`"}], ",", 
     RowBox[{"-", "0.13722841981944262`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.005987831055772856`", ",", "0.009064030735866832`", ",", 
     RowBox[{"-", "0.007520552110796329`"}], ",", "0.`", ",", 
     RowBox[{"-", "0.0697727963363848`"}], ",", 
     RowBox[{"-", "0.007520552110796315`"}], ",", "0.008928398429871883`", 
     ",", "0.04778005315991663`", ",", 
     RowBox[{"-", "0.002840260804123825`"}], ",", "0.008928398426333094`", 
     ",", "0.04778005315989419`", ",", 
     RowBox[{"-", "0.01220084341746878`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.010496371822499254`"}], ",", 
     RowBox[{"-", "0.08441792579815281`"}], ",", "0.015416440651970589`", ",",
      
     RowBox[{"-", "0.210172691733591`"}], ",", 
     RowBox[{"-", "0.07713901482717857`"}], ",", "0.015416440651970597`", ",",
      "0.08756278620010959`", ",", "0.0214790620334668`", ",", 
     "0.17149020684937227`", ",", "0.08756278608210172`", ",", 
     RowBox[{"-", "0.19746412271999964`"}], ",", 
     RowBox[{"-", "0.1406573255454311`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.422719375875*^9, 3.422720356953125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modes", ".", "hessian", ".", 
  RowBox[{"Transpose", "[", "modes", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.38636086487196464`", ",", 
     RowBox[{"-", "1.249000902703301`*^-16"}], ",", 
     RowBox[{"-", "1.734723475976807`*^-18"}], ",", 
     RowBox[{"-", "1.3877787807814457`*^-17"}], ",", 
     RowBox[{"-", "4.163336342344337`*^-17"}], ",", 
     RowBox[{"-", "1.7456942515945147`*^-17"}], ",", 
     RowBox[{"-", "1.2823132381160202`*^-6"}], ",", "1.3513083949728832`*^-7",
      ",", "7.264907073631366`*^-7", ",", "1.6790640031578985`*^-6", ",", 
     "5.2714176599103976`*^-8", ",", "1.7576602767341298`*^-6"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1102230246251565`*^-16"}], ",", "0.36844753875973124`", 
     ",", "8.153200337090993`*^-17", ",", "6.938893903907228`*^-17", ",", 
     "2.7755575615628914`*^-17", ",", 
     RowBox[{"-", "2.571058380667381`*^-17"}], ",", 
     RowBox[{"-", "1.73007146803128`*^-11"}], ",", 
     RowBox[{"-", "8.712675372835044`*^-11"}], ",", 
     "1.3153617084427083`*^-11", ",", "1.7960754411516788`*^-11", ",", 
     "5.19511408718365`*^-12", ",", "1.704426530468872`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.336808689942018`*^-18"}], ",", "8.153200337090993`*^-17",
      ",", "0.15522241811046453`", ",", "3.0357660829594124`*^-17", ",", 
     "9.540979117872439`*^-18", ",", 
     RowBox[{"-", "7.747758508100433`*^-18"}], ",", 
     RowBox[{"-", "4.095215919847073`*^-12"}], ",", "9.405136413599691`*^-11",
      ",", 
     RowBox[{"-", "1.2076640685740325`*^-12"}], ",", 
     "1.0305470452692811`*^-11", ",", 
     RowBox[{"-", "4.550962769611297`*^-12"}], ",", 
     "1.2637398506126774`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0816681711721685`*^-17"}], ",", 
     "6.591949208711867`*^-17", ",", "2.6020852139652106`*^-17", ",", 
     "0.10532599810164303`", ",", 
     RowBox[{"-", "1.3877787807814457`*^-17"}], ",", 
     RowBox[{"-", "3.321549500667269`*^-17"}], ",", 
     RowBox[{"-", "5.222734571208587`*^-12"}], ",", 
     "1.1101825708736968`*^-10", ",", 
     RowBox[{"-", "1.2037384977681143`*^-12"}], ",", 
     "1.2671504470707085`*^-11", ",", 
     RowBox[{"-", "5.3539149025630395`*^-12"}], ",", 
     "1.5447029072523932`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0816681711721685`*^-17"}], ",", "2.42861286636753`*^-17",
      ",", "7.806255641895632`*^-18", ",", 
     RowBox[{"-", "1.3877787807814457`*^-17"}], ",", "0.07173375951850036`", 
     ",", 
     RowBox[{"-", "2.0714177357503526`*^-16"}], ",", 
     "1.1919136512364772`*^-6", ",", 
     RowBox[{"-", "1.2555334163912718`*^-7"}], ",", 
     RowBox[{"-", "6.752967023626599`*^-7"}], ",", 
     RowBox[{"-", "1.5612149761624894`*^-6"}], ",", 
     RowBox[{"-", "4.9000772257270717`*^-8"}], ",", 
     RowBox[{"-", "1.6342991523152564`*^-6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7456942515945144`*^-17"}], ",", 
     RowBox[{"-", "2.571058380667379`*^-17"}], ",", 
     RowBox[{"-", "7.747758508100431`*^-18"}], ",", 
     RowBox[{"-", "3.3215495006672677`*^-17"}], ",", 
     RowBox[{"-", "2.0714177357503526`*^-16"}], ",", "0.06750927162965036`", 
     ",", 
     RowBox[{"-", "4.7269988002434784`*^-7"}], ",", 
     RowBox[{"-", "4.0775029361372274`*^-7"}], ",", 
     RowBox[{"-", "6.476044015735563`*^-7"}], ",", 
     RowBox[{"-", "4.574864779368386`*^-8"}], ",", 
     RowBox[{"-", "2.4468920927376056`*^-7"}], ",", 
     "2.2622614480557472`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2823132381097517`*^-6"}], ",", 
     RowBox[{"-", "1.730071224609893`*^-11"}], ",", 
     RowBox[{"-", "4.09521511975828`*^-12"}], ",", 
     RowBox[{"-", "5.222732031486174`*^-12"}], ",", "1.1919136512403516`*^-6",
      ",", 
     RowBox[{"-", "4.7269988002332896`*^-7"}], ",", "5.723237967851359`*^-7", 
     ",", "7.297405166102207`*^-8", ",", 
     RowBox[{"-", "5.75381029465895`*^-8"}], ",", 
     RowBox[{"-", "5.553755100630785`*^-7"}], ",", "5.344296773160549`*^-8", 
     ",", 
     RowBox[{"-", "6.019180057597266`*^-7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3513083949962764`*^-7", ",", 
     RowBox[{"-", "8.71267483438414`*^-11"}], ",", "9.405136299961949`*^-11", 
     ",", "1.1101826485278245`*^-10", ",", 
     RowBox[{"-", "1.2555334164433093`*^-7"}], ",", 
     RowBox[{"-", "4.077502936136587`*^-7"}], ",", "7.297405166111753`*^-8", 
     ",", "1.0685381612902291`*^-7", ",", "1.887303290344697`*^-7", ",", 
     "7.138740993761361`*^-8", ",", "6.340559394163506`*^-8", ",", 
     "5.699683108917336`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.264907073508411`*^-7", ",", "1.315360996532692`*^-11", ",", 
     RowBox[{"-", "1.2076633934292166`*^-12"}], ",", 
     RowBox[{"-", "1.2037362563601171`*^-12"}], ",", 
     RowBox[{"-", "6.752967023647828`*^-7"}], ",", 
     RowBox[{"-", "6.476044015734178`*^-7"}], ",", 
     RowBox[{"-", "5.7538102944276374`*^-8"}], ",", "1.8873032903360455`*^-7",
      ",", "3.9796723800342127`*^-7", ",", "3.405103558745674`*^-7", ",", 
     "1.0781221780152459`*^-7", ",", "3.2829633838485074`*^-7"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
    "1.6790640031520802`*^-6", ",", "1.796075576486368`*^-11", ",", 
     "1.0305471828764008`*^-11", ",", "1.2671505671376287`*^-11", ",", 
     RowBox[{"-", "1.5612149761659118`*^-6"}], ",", 
     RowBox[{"-", "4.57486477943457`*^-8"}], ",", 
     RowBox[{"-", "5.553755100615252`*^-7"}], ",", "7.138740993599939`*^-8", 
     ",", "3.405103558727659`*^-7", ",", "7.460198545961701`*^-7", ",", 
     "3.022332599167686`*^-8", ",", "7.789687788093633`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.271417659877219`*^-8", ",", "5.195113584247911`*^-12", ",", 
     RowBox[{"-", "4.550962571279029`*^-12"}], ",", 
     RowBox[{"-", "5.353915283132296`*^-12"}], ",", 
     RowBox[{"-", "4.9000772257199175`*^-8"}], ",", 
     RowBox[{"-", "2.4468920927390324`*^-7"}], ",", "5.3442967731661425`*^-8",
      ",", "6.340559394160055`*^-8", ",", "1.078122178011838`*^-7", ",", 
     "3.0223325991732426`*^-8", ",", "3.759525168666602`*^-8", ",", 
     "2.1015219926313094`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.757660276727336`*^-6", ",", "1.704426520749169`*^-11", ",", 
     "1.2637399726688016`*^-11", ",", "1.5447030786071585`*^-11", ",", 
     RowBox[{"-", "1.6342991523178432`*^-6"}], ",", "2.2622614477824325`*^-8",
      ",", 
     RowBox[{"-", "6.019180057577904`*^-7"}], ",", "5.699683108720642`*^-8", 
     ",", "3.282963383830777`*^-7", ",", "7.789687788081`*^-7", ",", 
     "2.1015219926261355`*^-8", ",", "1.1021283190579874`*^-6"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4227193760625*^9, 3.42272035709375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Get the dipole derivatives, IR intensities and polarizability derivatives for \
each normal mode\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"nmdipolederiv", "=", 
   RowBox[{"modes", ".", "dipolederiv"}]}], ";", 
  RowBox[{"MatrixForm", "[", "nmdipolederiv", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.3692229347944381`", 
      RowBox[{"-", "1.973353423726938`*^-17"}], 
      RowBox[{"-", "3.797309688913231`*^-15"}]},
     {
      RowBox[{"-", "1.6250882584056825`*^-11"}], "7.303694823854004`*^-18", 
      "0.22417464088483532`"},
     {
      RowBox[{"-", "4.609695437862715`*^-12"}], 
      RowBox[{"-", "9.798621367986585`*^-19"}], 
      RowBox[{"-", "0.38854521579245016`"}]},
     {
      RowBox[{"-", "9.182668514462478`*^-12"}], 
      RowBox[{"-", "8.937086703905341`*^-18"}], "0.10126216222345243`"},
     {"0.15341435615473664`", 
      RowBox[{"-", "2.3231927615947375`*^-17"}], 
      RowBox[{"-", "3.0878077872387166`*^-16"}]},
     {
      RowBox[{"-", "2.8440499545146405`*^-16"}], "0.025131140895668987`", 
      RowBox[{"-", "2.624555330009206`*^-17"}]},
     {
      RowBox[{"-", "0.06817578080696998`"}], "0.07127762810168281`", 
      RowBox[{"-", "8.843064301655712`*^-12"}]},
     {"0.00718320605650798`", "0.061484919342796804`", 
      "9.317702859279464`*^-13"},
     {"0.03862528774952324`", "0.09765118978175973`", 
      "5.0100583404155685`*^-12"},
     {"0.08928167288951015`", "0.0069035400080564345`", 
      "1.1580685195522467`*^-11"},
     {"0.002802680238459413`", "0.036900569214568746`", 
      "3.6351694224223685`*^-13"},
     {"0.09346101198291532`", 
      RowBox[{"-", "0.003406994256268975`"}], "1.2122788883850433`*^-11"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4227193761875*^9, 3.42272035728125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IRintensity", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"974.875", 
     RowBox[{
      RowBox[{"nmdipolederiv", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ".", 
      RowBox[{"nmdipolederiv", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"3", "Natoms"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "132.90039549181515`", ",", "48.991631091746775`", ",", 
   "147.1743291742322`", ",", "9.996393107527306`", ",", 
   "22.944623561928776`", ",", "0.6157059398696773`", ",", 
   "9.484010367861218`", ",", "3.7357149127249896`", ",", 
   "10.750597568073617`", ",", "7.817401719630195`", ",", 
   "1.335098160878164`", ",", "8.526810840418227`"}], "}"}]], "Output",
 CellChangeTimes->{3.4227193763125*^9, 3.42272035740625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"nmpolarderiv", "=", 
   RowBox[{"modes", ".", "polarderiv"}]}], ";", 
  RowBox[{"MatrixForm", "[", "nmpolarderiv", "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "1.9317880628477724`*^-13"}]},
          {"0.`"},
          {"5.973018414237739`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "1.1102230246251565`*^-14"}]},
          {"1.4628363873147384`*^-16"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"5.973018414237739`"},
          {"1.4628363873147384`*^-16"},
          {
           RowBox[{"-", "5.773159728050814`*^-14"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"11.101692410426494`"},
          {"0.`"},
          {"7.356604214692197`*^-11"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.6251665080296679`"},
          {
           RowBox[{"-", "6.357790375661304`*^-17"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"7.356604214692197`*^-11"},
          {
           RowBox[{"-", "6.357790375661304`*^-17"}]},
          {"3.390424071185798`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "0.48706723843075095`"}]},
          {"0.`"},
          {"2.0832807701154366`*^-11"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.5518616729901551`"},
          {"3.348201600045592`*^-17"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"2.0832807701154366`*^-11"},
          {"3.348201600045592`*^-17"},
          {"2.8993416575312114`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"1.3741796776085742`"},
          {"0.`"},
          {"4.1496361902204626`*^-11"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"0.11000483347765226`"},
          {"1.5744331842803933`*^-16"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"4.1496361902204626`*^-11"},
          {"1.5744331842803933`*^-16"},
          {
           RowBox[{"-", "3.5387457575309207`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "1.6431300764452317`*^-14"}]},
          {"0.`"},
          {
           RowBox[{"-", "1.6040211715944803`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "1.6375789613221059`*^-15"}]},
          {"8.030110237886055`*^-16"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "1.6040211715944803`"}]},
          {"8.030110237886055`*^-16"},
          {"1.1102230246251565`*^-14"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "9.768238461103115`*^-16"}]},
          {"2.220446049250313`*^-16"},
          {"2.0911947731786546`*^-15"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"2.220446049250313`*^-16"},
          {
           RowBox[{"-", "7.54280993170224`*^-17"}]},
          {
           RowBox[{"-", "0.6460262807791699`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"2.0911947731786546`*^-15"},
          {
           RowBox[{"-", "0.6460262807791699`"}]},
          {"4.595545187702614`*^-16"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "9.013847446226464`*^-10"}]},
          {"0.`"},
          {"0.3080839605103794`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {
           RowBox[{"-", "4.358500886592065`*^-11"}]},
          {
           RowBox[{"-", "0.7558497723077107`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.3080839605103794`"},
          {
           RowBox[{"-", "0.7558497723077107`"}]},
          {
           RowBox[{"-", "4.093185790310372`*^-10"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"1.5254485286053665`*^-8"},
          {
           RowBox[{"-", "1.942890293094024`*^-15"}]},
          {
           RowBox[{"-", "0.03246064302301105`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "1.942890293094024`*^-15"}]},
          {"4.592225905097891`*^-12"},
          {
           RowBox[{"-", "0.6520049108601991`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "0.03246064302301105`"}]},
          {
           RowBox[{"-", "0.6520049108601991`"}]},
          {"1.5202637759781368`*^-8"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "6.056519175068331`*^-11"}]},
          {"0.`"},
          {
           RowBox[{"-", "0.17454632510036058`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.`"},
          {"2.4693256120422724`*^-11"},
          {
           RowBox[{"-", "1.0355230880694464`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "0.17454632510036058`"}]},
          {
           RowBox[{"-", "1.0355230880694464`"}]},
          {
           RowBox[{"-", "3.3934702270421724`*^-10"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"1.980747288410356`*^-9"},
          {
           RowBox[{"-", "2.5646151868841116`*^-14"}]},
          {
           RowBox[{"-", "0.403460878478459`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "2.5646151868841116`*^-14"}]},
          {"5.7078067966509494`*^-11"},
          {
           RowBox[{"-", "0.0732073491978426`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "0.403460878478459`"}]},
          {
           RowBox[{"-", "0.0732073491978426`"}]},
          {"1.3363478101879878`*^-9"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "7.271263313679555`*^-10"}]},
          {"4.088396288182139`*^-14"},
          {
           RowBox[{"-", "0.012665214337117321`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"4.088396288182139`*^-14"},
          {"1.7917772300590773`*^-12"},
          {
           RowBox[{"-", "0.39130500604856217`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "0.012665214337117321`"}]},
          {
           RowBox[{"-", "0.39130500604856217`"}]},
          {
           RowBox[{"-", "7.473547822267612`*^-10"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"2.372953333829031`*^-9"},
          {"0.39892094144476603`"},
          {
           RowBox[{"-", "0.42234717245913234`"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0.39892094144476603`"},
          {"5.974995151425411`*^-11"},
          {"0.0361287282517552`"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {
           RowBox[{"-", "0.42234717245913234`"}]},
          {"0.0361287282517552`"},
          {"1.698388818471841`*^-9"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        Column], "\[NoBreak]", ")"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.422719376453125*^9, 3.4227203575625*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1045, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 20, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 43, 0, 49, "Subtitle"],
Cell[636, 25, 1123, 21, 137, "Text"],
Cell[CellGroupData[{
Cell[1784, 50, 69, 0, 36, "Subsection"],
Cell[1856, 52, 91, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[1972, 58, 183, 3, 31, "Input"],
Cell[2158, 63, 171, 3, 30, "Output"]
}, Open  ]],
Cell[2344, 69, 199, 4, 31, "Input"],
Cell[2546, 75, 458, 17, 31, "Input"],
Cell[3007, 94, 2788, 88, 132, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5832, 187, 77, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[5934, 191, 457, 13, 31, "Input"],
Cell[6394, 206, 2061, 28, 335, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8504, 240, 67, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[8596, 244, 3006, 90, 132, "Input"],
Cell[CellGroupData[{
Cell[11627, 338, 460, 9, 23, "Print"],
Cell[12090, 349, 443, 8, 23, "Print"],
Cell[12536, 359, 485, 9, 23, "Print"],
Cell[13024, 370, 502, 11, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13587, 388, 40, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[13652, 392, 1014, 30, 92, "Input"],
Cell[14669, 424, 176, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14894, 434, 44, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[14963, 438, 1126, 33, 92, "Input"],
Cell[16092, 473, 1255, 37, 206, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17396, 516, 43, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[17464, 520, 1400, 42, 92, "Input"],
Cell[18867, 564, 720, 19, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19636, 589, 52, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[19713, 593, 1612, 48, 92, "Input"],
Cell[21328, 643, 24683, 702, 578, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46060, 1351, 61, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[46146, 1355, 1490, 44, 92, "Input"],
Cell[47639, 1401, 6623, 188, 164, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54311, 1595, 51, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[54387, 1599, 1684, 51, 92, "Input"],
Cell[56074, 1652, 3118, 71, 206, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59241, 1729, 45, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[59311, 1733, 831, 25, 72, "Input"],
Cell[60145, 1760, 350, 7, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60544, 1773, 105, 1, 36, "Subsection"],
Cell[60652, 1776, 4444, 68, 312, "Input"],
Cell[CellGroupData[{
Cell[65121, 1848, 1882, 48, 112, "Input"],
Cell[67006, 1898, 989, 22, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68044, 1926, 91, 2, 36, "Subsection"],
Cell[68138, 1930, 1190, 38, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69365, 1973, 141, 3, 36, "Subsection"],
Cell[69509, 1978, 617, 19, 52, "Input"],
Cell[70129, 1999, 562, 17, 31, "Input"],
Cell[70694, 2018, 562, 17, 31, "Input"],
Cell[71259, 2037, 794, 24, 52, "Input"],
Cell[72056, 2063, 794, 24, 52, "Input"],
Cell[72853, 2089, 800, 24, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73690, 2118, 67, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[73782, 2122, 159, 4, 31, "Input"],
Cell[73944, 2128, 4759, 97, 251, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78752, 2231, 120, 3, 36, "Subsection"],
Cell[78875, 2236, 642, 19, 31, "Input"],
Cell[CellGroupData[{
Cell[79542, 2259, 30, 0, 31, "Input"],
Cell[79575, 2261, 720, 15, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80332, 2281, 31, 0, 31, "Input"],
Cell[80366, 2283, 6441, 133, 344, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86844, 2421, 109, 2, 31, "Input"],
Cell[86956, 2425, 6762, 136, 451, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93767, 2567, 126, 3, 36, "Subsection"],
Cell[CellGroupData[{
Cell[93918, 2574, 171, 4, 31, "Input"],
Cell[94092, 2580, 1991, 48, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96120, 2633, 389, 12, 31, "Input"],
Cell[96512, 2647, 467, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97016, 2661, 168, 4, 31, "Input"],
Cell[97187, 2667, 26685, 722, 640, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
